@@ -19,7 +19,9 @@ Some code was adapted from containers.
 {-# LANGUAGE TypeOperators #-}
 {-# LANGUAGE Trustworthy #-}
 {-# LANGUAGE TypeFamilies #-}
+#if __GLASGOW_HASKELL__ < 806
 {-# LANGUAGE TypeInType #-}
+#endif
 module Data.Parameterized.Map
   ( MapF
     -- * Construction
@@ -81,7 +83,8 @@ module Data.Parameterized.Map
 
 import           Control.Applicative hiding (empty)
 import           Control.Lens (Traversal', Lens')
-import           Control.Monad.Identity
+import           Control.Monad.Identity (Identity(..))
+import           Control.Monad (foldM)
 import           Data.Kind (Type)
 import           Data.List (intercalate, foldl')
 import           Data.Monoid
